==> Botania-1.20.1-449-FABRIC-20250601.081344-21-sources.jar: vazkii/botania/api/internal/ManaBurst.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.api.internal;

import org.jetbrains.annotations.Nullable;

import java.util.UUID;
import net.minecraft.class_1682;
import net.minecraft.class_1799;
import net.minecraft.class_2338;

public interface ManaBurst {
	/**
	 * Used a sentinel "no position" position. Note that using BlockPos.ZERO is incorrect
	 * in most cases, due to the world height limit now going below y=0.
	 */
	class_2338 NO_SOURCE = new class_2338(0, Integer.MIN_VALUE, 0);

	boolean isFake();

	int getColor();

	void setColor(int color);

	int getMana();

	void setMana(int mana);

	int getStartingMana();

	void setStartingMana(int mana);

	int getMinManaLoss();

	void setMinManaLoss(int minManaLoss);

	float getManaLossPerTick();

	void setManaLossPerTick(float mana);

	float getBurstGravity();

	void setGravity(float gravity);

	/**
	 * The block position of the block entity that spawned this burst.
	 * If the burst wasn't fired from a block entity, returns {@link #NO_SOURCE}
	 */
	class_2338 getBurstSourceBlockPos();

	void setBurstSourceCoords(class_2338 pos);

	class_1799 getSourceLens();

	void setSourceLens(class_1799 lens);

	boolean hasAlreadyCollidedAt(class_2338 pos);

	void setCollidedAt(class_2338 pos);

	int getTicksExisted();

	void setFake(boolean fake);

	void setShooterUUID(UUID uuid);

	UUID getShooterUUID();

	void ping();

	/**
	 * @return True if a warp lens has already warped this burst once
	 */
	boolean hasWarped();

	void setWarped(boolean warped);

	int getOrbitTime();

	void setOrbitTime(int time);

	/**
	 * @return Whether an entity has tripped this burst for the tripwire lens
	 */
	boolean hasTripped();

	void setTripped(boolean tripped);

	/**
	 * @return The position this burst is magnetized towards
	 */
	@Nullable
	class_2338 getMagnetizedPos();

	void setMagnetizePos(@Nullable class_2338 pos);

	/**
	 * @return True if the burst has ticked at least once outside of {@link #getBurstSourceBlockPos()}.
	 */
	boolean hasLeftSource();

	default class_1682 entity() {
		return (class_1682) this;
	}
}

==> Botania-1.20.1-451-FABRIC-20260119.100843-40-sources.jar: vazkii/botania/api/internal/ManaBurst.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.api.internal;

import org.jetbrains.annotations.Nullable;

import java.util.Optional;
import java.util.UUID;
import net.minecraft.class_1682;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_2338;
import net.minecraft.class_4208;

public interface ManaBurst {
	/**
	 * Used a sentinel "no position" position. Note that using BlockPos.ZERO is incorrect
	 * in most cases, due to the world height limit now going below y=0.
	 */
	class_2338 NO_SOURCE = new class_2338(0, Integer.MIN_VALUE, 0);

	boolean isFake();

	int getColor();

	void setColor(int color);

	int getMana();

	void setMana(int mana);

	int getStartingMana();

	void setStartingMana(int mana);

	int getMinManaLoss();

	void setMinManaLoss(int minManaLoss);

	float getManaLossPerTick();

	void setManaLossPerTick(float mana);

	float getBurstGravity();

	void setGravity(float gravity);

	/**
	 * The block position of the block entity that spawned this burst.
	 * If the burst wasn't fired from a block entity, returns {@link #NO_SOURCE}
	 */
	class_2338 getBurstSourceBlockPos();

	void setBurstSourceCoords(class_2338 pos);

	Optional<class_4208> getBurstSource();

	void setBurstSource(@Nullable class_4208 sourcePos);

	default boolean isBurstSourceDimension(class_1937 testLevel) {
		return getBurstSource().map(class_4208::method_19442).map(testLevel.method_27983()::equals).orElse(false);
	}

	class_1799 getSourceLens();

	void setSourceLens(class_1799 lens);

	boolean hasAlreadyCollidedAt(class_2338 pos);

	void setCollidedAt(class_2338 pos);

	int getTicksExisted();

	void setFake(boolean fake);

	void setShooterUUID(UUID uuid);

	UUID getShooterUUID();

	void ping();

	/**
	 * @return True if a warp lens has already warped this burst once
	 */
	boolean hasWarped();

	void setWarped(boolean warped);

	int getOrbitTime();

	void setOrbitTime(int time);

	/**
	 * @return Whether an entity has tripped this burst for the tripwire lens
	 */
	boolean hasTripped();

	void setTripped(boolean tripped);

	/**
	 * @return The position this burst is magnetized towards
	 */
	@Nullable
	class_2338 getMagnetizedPos();

	void setMagnetizePos(@Nullable class_2338 pos);

	/**
	 * @return True if the burst has ticked at least once outside of {@link #getBurstSourceBlockPos()}.
	 */
	boolean hasLeftSource();

	default class_1682 entity() {
		return (class_1682) this;
	}
}
